summaryrefslogtreecommitdiffstats
path: root/src/com/android/camera/CameraActivity.java
diff options
context:
space:
mode:
authorMangesh Ghiware <mghiware@google.com>2013-09-11 15:59:59 -0700
committerMangesh Ghiware <mghiware@google.com>2013-09-26 17:32:12 -0700
commit06c027675948259368a902fd6f8c2ecac5db5167 (patch)
treebcd3c500b5d3d470a8132f40cb704ffcaa2453af /src/com/android/camera/CameraActivity.java
parent641be74bd9d3f96d8665b23121f40efb8df2ea83 (diff)
downloadandroid_packages_apps_Gallery2-06c027675948259368a902fd6f8c2ecac5db5167.tar.gz
android_packages_apps_Gallery2-06c027675948259368a902fd6f8c2ecac5db5167.tar.bz2
android_packages_apps_Gallery2-06c027675948259368a902fd6f8c2ecac5db5167.zip
Rename Gallery activity and add trampoline
Bug: 10807861 Change-Id: Iaaf17b579db2fe09900e9817f766f43dd66dea61
Diffstat (limited to 'src/com/android/camera/CameraActivity.java')
-rw-r--r--src/com/android/camera/CameraActivity.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/com/android/camera/CameraActivity.java b/src/com/android/camera/CameraActivity.java
index f2402af7d..533bbe878 100644
--- a/src/com/android/camera/CameraActivity.java
+++ b/src/com/android/camera/CameraActivity.java
@@ -15,18 +15,18 @@
*/
package com.android.camera;
-import com.android.gallery3d.util.CameraHelper;
+import com.android.gallery3d.util.IntentHelper;
import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
/** Trampoline activity that launches the new Camera activity defined in CameraHelper. */
public class CameraActivity extends Activity {
@Override
public void onCreate(Bundle icicle) {
super.onCreate(icicle);
- Intent intent = CameraHelper.CAMERA_LAUNCHER_INTENT;
+ Intent intent = IntentHelper.CAMERA_LAUNCHER_INTENT;
// Since this is being launched from a homescreen shorcut,
// it's already in a new task. Start Camera activity and
// reset the task to its initial state if needed.
@@ -15,18 +15,18 @@
import android.content.Intent;
import android.os.Bundle;
-/** Trampoline activity that launches the new Camera activity defined in CameraHelper. */
+/** Trampoline activity that launches the new Camera activity defined in IntentHelper. */
public class CameraActivity extends Activity {